@@ -4,8 +4,8 @@ from ._version import semver
 
 
 class ForceLoad(DOMWidget):
-    _model_name = Unicode('ForceLoadModel').tag(sync=True)
-    _model_module = Unicode('jupyter-vue').tag(sync=True)
+    _model_name = Unicode("ForceLoadModel").tag(sync=True)
+    _model_module = Unicode("jupyter-vue").tag(sync=True)
     _model_module_version = Unicode(semver).tag(sync=True)
 
 
