@@ -1,4 +1,8 @@
 import "core-js/modules/es.array.iterator";
+import "core-js/modules/es.promise";
+import "core-js/modules/es.regexp.constructor";
+import "core-js/modules/es.regexp.to-string";
+import "core-js/modules/es.string.match";
 import "core-js/modules/web.dom-collections.iterator";
 
 function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }
@@ -11,6 +15,7 @@ function _defineProperty(obj, key, value) { if (key in obj) { Object.definePrope
 import { DOMWidgetModel } from '@jupyter-widgets/base';
 import Vue from 'vue';
 import httpVueLoader from './httpVueLoader';
+import { TemplateModel } from './Template';
 export class VueComponentModel extends DOMWidgetModel {
   defaults() {
     return _objectSpread({}, super.defaults(), {}, {
@@ -24,9 +29,38 @@ export class VueComponentModel extends DOMWidgetModel {
 
   constructor(...args) {
     super(...args);
-    Vue.component(this.get('name'), httpVueLoader(this.get('component')));
+    const [, {
+      widget_manager
+    }] = args;
+    const name = this.get('name');
+    Vue.component(name, httpVueLoader(this.get('component')));
     this.on('change:component', () => {
-      Vue.component(this.get('name'), httpVueLoader(this.get('component')));
+      Vue.component(name, httpVueLoader(this.get('component')));
+
+      (async () => {
+        const models = await Promise.all(Object.values(widget_manager._models));
+        const componentModels = models.filter(model => model instanceof VueComponentModel);
+        const affectedComponents = [];
+
+        function re(searchName) {
+          return new RegExp("\\<".concat(searchName, "[ />\n]"), 'g');
+        }
+
+        function find_usage(searchName) {
+          affectedComponents.push(searchName);
+          componentModels.filter(model => model.get('component').match(re(searchName))).forEach(model => {
+            const cname = model.get('name');
+
+            if (!affectedComponents.includes(cname)) {
+              find_usage(cname);
+            }
+          });
+        }
+
+        find_usage(name);
+        const affectedTemplateModels = models.filter(model => model instanceof TemplateModel && affectedComponents.some(cname => model.get('template').match(re(cname))));
+        affectedTemplateModels.forEach(model => model.trigger('change:template'));
+      })();
     });
   }
 
